# Abuse: World's First Profanity Library™


**Behold, the power of Abuse v1:**


- Let's import the beast first :

```
>>>import abuse as ab
>>>ab.ListAbusesFrom("a")

['...', '...', '...'] #gives a list of abuses starting with the letter 'a'
```



**Abuse** allows you to use profanity when you need it, without the need for getting angry. There's no need to manually search curse words from **Google**, or to ask anybody. Abuse is 100% automatic, thanks to Python.

Besides, all the cool kids are doing it. You should try it!


# Feature Support

> Abuse is in it's beta.

- `ListAbusesFrom()` : Returns list of abuses starting from a specific letter.
- `RandomAbuseFrom()` : Returns a random abuse starting from a specific letter.
- `ListAnyAbuse()` : Returns any random abuse from it's built-in dataset.
- `ListAllAbuses()` : Returns list of abuses in it's database.


_Abuse officially supports Python 3.4–3.7, but can also run on Python 2._


# Installation

To install Abuse, simply use pipenv _(or pip, of course)_:

- For Linux :

```
$ pip install abuse
```
OR
```
$ pipenv install abuse
```

- For Windows :

```
C:\Python34\Scripts> pip install abuse
```
OR
```
C:\>py -3 -m pip install abuse
```

**Satisfaction guaranteed.**



# Documentation
Fantastic documentation will be available in some days, for a limited time only.